#!/bin/sh
#set -x 
# script to help determine what is using backup space
# written by Adrian Bridgett

topdir="/var/lib/backuppc"
size="1048576"
backup="last"

set -e

usage()
{
  cat <<EOF
Usage: `basename $0` -a|-h hostname [-s size] [-b last|full|incr|number]

reports new files (above a the given size (default=$size)
in a given backup (defaults to "$backup") 

EOF
  exit 1
}

main()
{
  hosts=""
  while getopts "ah:s:b:" opt; do
    case "$opt" in
      h) hosts="$hosts $OPTARG";;
      a) hosts=`/bin/ls "$topdir/pc"`;;
      s) size=$OPTARG;;
      b) backup="$OPTARG";;
    esac
  done
  shift $(($OPTIND - 1))

  [ "$hosts" ] || usage

  for host in $hosts; do
    print_new $host
    echo
  done
}

# report last full or incr backup
get_last()
{
  type="$1"
  num=`awk -v type="$type" '{ if ($2 == type) backup=$1 }  
                      END { print backup }' $topdir/pc/$host/backups`
  echo $topdir/pc/$host/XferLOG.$num.z
}

print_new()
{
  local host="$1"
  echo "$host"
  echo "========="
  case "$backup" in
    last) file=`ls -rt $topdir/pc/$host/XferLOG* | tail -n1`;;
    full|incr) file=`get_last $backup`;;
    *) file="$topdir/pc/$host/XferLOG.$backup.z";;
  esac
  
  /usr/share/backuppc/bin/BackupPC_zcat $file | \
    awk -v size=$size \
      '/^  create   / {if ($4 >= size) print $0}' | sort -n -k 4
}

main "$@"


